<?php

namespace Lavalite\Example\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Lavalite\Example\Actions\ExampleExim;
use Lavalite\Example\Http\Requests\ExampleEximRequest;

/**
 * Admin web controller class.
 */
class ExampleEximController extends BaseController
{
    /**
     * Action controller function for example.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ExampleEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = ExampleExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('example:example.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('example/example/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('example/example/' . $exim))
                ->redirect();
        }
    }
}
