<?php

namespace Lavalite\Example\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Lavalite\Example\Http\Resources\ExampleResource;
use Lavalite\Example\Http\Resources\ExamplesCollection;
use Lavalite\Example\Scopes\ExamplePublicScope;
use Lavalite\Example\Models\Example;

class ExamplePublicController extends BaseController
{

    /**
     * Show example's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Example::pushScope(new RequestScope())
            ->pushScope(new ExamplePublicScope())
            ->select('examples.*')
            ->paginate($pageLimit)
            ->withQueryString();

        $data = new ExamplesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('example::example.names'))
            ->view('example::public.example.index')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show example.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Example::findBySlug($slug);
        $data = new ExampleResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('example::example.name'))
            ->view('example::public.example.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
