<?php

namespace Lavalite\Example\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Lavalite\Example\Actions\ExampleReport;
use Lavalite\Example\Http\Requests\ExampleReportRequest;

/**
 * Admin web controller class.
 */
class ExampleReportController extends BaseController
{
    /**
     * Action controller function for example.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ExampleReportRequest $request, $report)
    {
        try {
        
            $this->model = app(Example::class);
            $data = ExampleReport::run($request, $report);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('example::example.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('example/example/' . $report))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('example/example/' . $report))
                ->redirect();
        }
    }
}
