<?php

namespace Lavalite\Example\Http\Controllers;

use Exception;
use Lavalite\Example\Actions\ExampleWorkflow;
use Lavalite\Example\Http\Requests\ExampleWorkflowRequest;
use Lavalite\Example\Http\Resources\ExampleResource;
use Lavalite\Example\Models\Example;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class ExampleWorkflowController extends BaseController
{
    /**
     * Action controller function for example.
     *
     * @param Model $example
     * @param action next action for the example.
     *
     * @return Response
     */
    public function __invoke(ExampleWorkflowRequest $request, Example $example, $trasition)
    {
        try {
            $example = ExampleWorkflow::run($request, $example, $trasition);
            $data = new ExampleResource($example);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('example::example.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('example/example/' . $example->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('example/example/' . $example->getRouteKey()))
                ->redirect();
        }
    }
}
