<?php

namespace Lavalite\Example\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Lavalite\Example\Models\Example;

class ExamplePolicy
{

    use ExampleExim;
    use ExampleReport;
    use ExampleWorkflow;

    /**
     * Determine if the given user can view the example.
     *
     * @param UserPolicyInterface $authUser
     * @param Example $example
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Example $example)
    {
        if ($authUser->canDo('example.example.view') && $authUser->isAdmin()) {
            return true;
        }

        return $example->user_id == user_id() && $example->user_type == user_type();
    }

    /**
     * Determine if the given user can create a example.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('example.example.create');
    }

    /**
     * Determine if the given user can update the given example.
     *
     * @param UserPolicyInterface $authUser
     * @param Example $example
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Example $example)
    {
        if ($authUser->canDo('example.example.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $example->user_id == user_id() && $example->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given example.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Example $example)
    {
        return $example->user_id == user_id() && $example->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given example.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Example $example)
    {
        if ($authUser->canDo('example.example.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given example.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Example $example)
    {
        if ($authUser->canDo('example.example.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
